%if 0%{?fedora}
# With _package_note_file enabled, godot.x11.opt.tools fails to link with:
# g++: fatal error: environment variable 'RPM_ARCH' not defined
%undefine _package_note_file
%endif

# Headless is editor binary to run without X11, e.g. for exporting games from CLI
%bcond_without  headless
# Server is template (optimized, no tools) binary to run multiplayer servers
%bcond_without  server

%define status  stable
%define uversion %{version}-%{status}

%define uname   godot
%define urdnsname org.godotengine.Godot
%define rdnsname %{urdnsname}3

Name:           godot3
Version:        3.6
Release:        %mkrel 1
Summary:        Multi-platform 2D and 3D game engine with a feature-rich editor (version 3)
%if 0%{?mageia}
Group:          Development/Tools
%endif
# Godot itself is MIT-licensed, the rest is from vendored thirdparty libraries
License:        MIT and CC-BY and ASL 2.0 and BSD and zlib and OFL and Bitstream Vera and ISC and MPLv2.0
URL:            https://godotengine.org
Source0:        https://github.com/godotengine/godot-builds/releases/download/%{uversion}/%{uname}-%{uversion}.tar.xz
Source1:        https://github.com/godotengine/godot-builds/releases/download/%{uversion}/%{uname}-%{uversion}.tar.xz.sha256

Patch0:         godot3-dist-files-rebranding.patch
# https://github.com/godotengine/godot/pull/97139
Patch1:         godot3-miniupnp228.patch
# https://github.com/godotengine/godot/pull/102023
Patch2:         0001-embree-Fix-invalid-output-operators-raising-errors-w.patch

# Upstream does not support those arches (for now)
ExcludeArch:    ppc64 ppc64le s390x

BuildRequires:  gcc-c++
BuildRequires:  mbedtls-devel
BuildRequires:  miniupnpc-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bullet) >= 2.89
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libpcre2-32)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libwslay)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(zlib)
%if 0%{?mageia}
BuildRequires:  scons
%else
BuildRequires:  python3-scons
%endif

%ifarch aarch64 x86_64
BuildRequires:  embree3-devel
%endif

# For desktop and appdata files validation
BuildRequires:  desktop-file-utils
%if 0%{?mageia}
BuildRequires:  appstream-util
%else
BuildRequires:  libappstream-glib
%endif

# Ensure the hicolor icon theme dirs exist
Requires:       hicolor-icon-theme

# Bundled libraries: many of the libraries code in `thirdparty` can be
# unbundled when the libraries are provided by the system. Keep in mind
# though that the `thirdparty` folder also contains code which is typically
# not packaged in distros, and is probably best left bundled.

# Has some modifications for IPv6 support, upstream enet is unresponsive.
# Upstream commit ea4607a90dbfbcf4da2669ea998585253d8e70b1 + security fix.
# Should not be unbundled.
# Cf: https://github.com/godotengine/godot/issues/6992
Provides:       bundled(enet) = 1.3.18
# Upstream commit from 2016 (32d5ac49414a8914ec1e1f285f3f927c6e8ec29d),
# newer than 1.0.0.27 which is the last tag.
# Could be unbundled if packaged.
Provides:       bundled(libwebm)
# Has custom changes to support seeking in zip archives
# Should not be unbundled.
Provides:       bundled(minizip) = 1.3.1
# Upstream commit 93ce879dc4c04a3ef1758428ec80083c38610b1f, no releases.
# Could be unbundled if packaged.
Provides:       bundled(nanosvg)
%ifarch x86_64
# Could be unbundled but requires some upstream work, and it's not clear if
# upstream code would be compatible with more recent OIDN releases.
Provides:       bundled(oidn) = 1.1.0
%endif
# Could be unbundled if packaged.
Provides:       bundled(squish) = 1.15
# Could be unbundled if packaged.
Provides:       bundled(tinyexr) = 1.0.8

%description
Godot 3 is an advanced, feature-packed, multi-platform 2D and 3D game engine.
It provides a huge set of common tools, so you can just focus on making
your game without reinventing the wheel.

Godot is completely free and open source under the very permissive MIT
license. No strings attached, no royalties, nothing. Your game is yours,
down to the last line of engine code.

%files
%doc CHANGELOG.md DONORS.md README.md
%license AUTHORS.md COPYRIGHT.txt LICENSE.txt LOGO_LICENSE.md
%{_bindir}/%{name}
%{_datadir}/applications/%{rdnsname}.desktop
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/fish/vendor_completions.d/%{name}.fish
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/metainfo/%{rdnsname}.appdata.xml
%{_datadir}/mime/application/%{rdnsname}.xml
%{_datadir}/zsh/site-functions/_%{name}
%{_mandir}/man6/%{name}.6*

#----------------------------------------------------------------------

%if %{with headless}
%package        headless
Summary:        Godot 3 headless editor binary for CLI usage
%if 0%{?mageia}
Group:          Development/Tools
%endif

%description    headless
This package contains the headless binary for the Godot 3 game engine,
particularly suited for CLI usage, e.g. to export projects from a server
or build system.

To run game servers, see the godot-server package which contains an
optimized template build.

%files          headless
%license AUTHORS.md COPYRIGHT.txt LICENSE.txt
%{_bindir}/%{name}-headless
%endif

#----------------------------------------------------------------------

%if %{with server}
%package        server
Summary:        Godot 3 headless runtime binary for hosting game servers
%if 0%{?mageia}
Group:          Games/Other
%endif

%description    server
This package contains the headless binary for the Godot 3 game engine's
runtime, useful to host standalone game servers.

To use editor tools from the command line, see the godot-headless
package.

%files          server
%license AUTHORS.md COPYRIGHT.txt LICENSE.txt
%{_bindir}/%{name}-server
%endif

#----------------------------------------------------------------------

%package        runner
Summary:        Shared binary to play games developed with the Godot 3 game engine
%if 0%{?mageia}
Group:          Games/Other
%endif

%description    runner
This package contains a godot-runner binary for the Linux X11 platform,
which can be used to run any game developed with the Godot 3 game engine
simply by pointing to the location of the game's data package.

%files          runner
%license AUTHORS.md COPYRIGHT.txt LICENSE.txt
%{_bindir}/%{name}-runner

#----------------------------------------------------------------------

%prep
%autosetup -p1 -n %{uname}-%{uversion}

# Patch for miniupnpc 2.2.8 (api 18)
sed -i 's/addr, 16/addr, 16, nullptr, 0/g' modules/upnp/upnp.cpp

%build
# Needs to be in %%build so that system_libs stays in scope
# We don't unbundle enet and minizip as they have necessary custom changes
to_unbundle="bullet embree freetype libogg libpng libtheora libvorbis libvpx libwebp mbedtls miniupnpc opus pcre2 wslay zlib zstd"

system_libs=""
for lib in $to_unbundle; do
    system_libs+="builtin_"$lib"=no "
    rm -rf thirdparty/$lib
done

# The denoise module depends on OIDN which is x86_64 only (in the vendored version).
# Godot's own logic to disable it on other arches is a bit brittle when it comes to cross-compiling currently.
%ifnarch x86_64
%define disable_modules module_denoise_enabled=no
%endif

%define _scons scons %{?_smp_mflags} "CCFLAGS=%{?build_cflags}" "LINKFLAGS=%{?build_ldflags}" $system_libs lto=full use_static_cpp=no progress=no %{?disable_modules}

%if 0%{?fedora}
export BUILD_NAME="fedora"
%endif
%if 0%{?mageia}
export BUILD_NAME="mageia"
%endif

# Build graphical editor (tools)
%_scons p=x11 tools=yes target=release_debug

# Build game runner (without tools)
%_scons p=x11 tools=no target=release

%if %{with headless}
# Build headless version of the editor
%_scons p=server tools=yes target=release_debug
%endif

%if %{with server}
# Build headless version of the runtime for servers
%_scons p=server tools=no target=release
%endif

%install
install -d %{buildroot}%{_bindir}
install -m755 bin/%{uname}.x11.opt.tools.%{__isa_bits} %{buildroot}%{_bindir}/%{name}
install -m755 bin/%{uname}.x11.opt.%{__isa_bits} %{buildroot}%{_bindir}/%{name}-runner
%if %{with headless}
install -m755 bin/%{uname}_server.x11.opt.tools.%{__isa_bits} %{buildroot}%{_bindir}/%{name}-headless
%endif
%if %{with server}
install -m755 bin/%{uname}_server.x11.opt.%{__isa_bits} %{buildroot}%{_bindir}/%{name}-server
%endif

install -D -m644 icon.svg \
    %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
install -D -m644 misc/dist/linux/%{urdnsname}.desktop \
    %{buildroot}%{_datadir}/applications/%{rdnsname}.desktop
install -D -m644 misc/dist/linux/%{urdnsname}.appdata.xml \
    %{buildroot}%{_datadir}/metainfo/%{rdnsname}.appdata.xml
install -D -m644 misc/dist/linux/%{urdnsname}.xml \
    %{buildroot}%{_datadir}/mime/application/%{rdnsname}.xml
install -D -m644 misc/dist/linux/%{uname}.6 \
    %{buildroot}%{_mandir}/man6/%{name}.6
install -D -m644 misc/dist/shell/%{uname}.bash-completion \
    %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -D -m644 misc/dist/shell/%{uname}.fish \
    %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish
install -D -m644 misc/dist/shell/_%{uname}.zsh-completion \
    %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

%check
# Validate desktop and appdata files
desktop-file-validate %{buildroot}%{_datadir}/applications/%{rdnsname}.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/%{rdnsname}.appdata.xml


%changelog
* Sun May 04 2025 daviddavid <daviddavid> 3.6-1.mga10
+ Revision: 2180785
- Version 3.6-stable
- Use system-provided embree3
- Fix build with GCC 15

* Wed Apr 30 2025 daviddavid <daviddavid> 3.5.3-5.mga10
+ Revision: 2180111
- rebuild for new libtheora 1.2.0

* Sun Jan 12 2025 daviddavid <daviddavid> 3.5.3-4.mga10
+ Revision: 2138626
- rebuild for new libvpx 1.14.1

* Thu Sep 05 2024 daviddavid <daviddavid> 3.5.3-3.mga10
+ Revision: 2093179
- add archlinux hack to fix build with miniupnpc 2.2.8
- rebuild for miniupnpc 2.2.8

* Tue Oct 10 2023 danf <danf> 3.5.3-2.mga10
+ Revision: 1994007
- Rebuild for new libvpx

* Mon Sep 25 2023 akien <akien> 3.5.3-1.mga10
+ Revision: 1990859
- Version 3.5.3

* Tue Apr 04 2023 akien <akien> 3.5.2-2.mga9
+ Revision: 1951418
- Fix desktop and other dist files for godot3 binary name
- Sync spec with my Fedora package

* Tue Mar 07 2023 akien <akien> 3.5.2-1.mga9
+ Revision: 1948078
- Version 3.5.2-stable
- Make system embree3 opt-in, Fedora 38+ only has incompatible embree4
- Rename godot to godot3, allow installing it next to godot 4
- Copy godot to godot3, preparing for Godot 4.0 release

* Thu Jan 12 2023 akien <akien> 3.5.2-0.rc2.1.mga9
+ Revision: 1932661
- Version 3.5.2-rc2

* Wed Dec 14 2022 akien <akien> 3.5.2-0.rc1.1.mga9
+ Revision: 1922062
- Version 3.5.2-rc1

* Thu Dec 08 2022 rapsys <rapsys> 3.5.1-3.mga9
+ Revision: 1919192
- rebuild for bullet 3.24 with double precision

* Tue Oct 11 2022 ghibo <ghibo> 3.5.1-2.mga9
+ Revision: 1896287
- Rebuild against libvpx 1.12.0 (changed major from 6 to 7)

* Wed Sep 28 2022 akien <akien> 3.5.1-1.mga9
+ Revision: 1892900
- Version 3.5.1-stable

* Fri Aug 05 2022 akien <akien> 3.5-1.mga9
+ Revision: 1875416
- Version 3.5

* Tue Aug 02 2022 akien <akien> 3.4.5-2.mga9
+ Revision: 1874334
- Version 3.4.5-stable
+ papoteur <papoteur>
- Mass Rebuild for dependencies

* Wed Mar 23 2022 akien <akien> 3.4.4-1.mga9
+ Revision: 1822633
- Version 3.4.4

* Fri Feb 25 2022 akien <akien> 3.4.3-1.mga9
+ Revision: 1784894
- Version 3.4.3

* Tue Jan 11 2022 akien <akien> 3.4.2-2.mga9
+ Revision: 1767968
- Rebuild for mbedtls 2.28.0

* Wed Dec 22 2021 akien <akien> 3.4.2-1.mga9
+ Revision: 1763281
- Version 3.4.2-stable

* Fri Dec 17 2021 akien <akien> 3.4.1-2.mga9
+ Revision: 1762401
- New upstream tarball with fixed version status (rc -> stable)

* Fri Dec 17 2021 akien <akien> 3.4.1-1.mga9
+ Revision: 1762383
- Version 3.4.1-stable

* Fri Nov 05 2021 akien <akien> 3.4-1.mga9
+ Revision: 1754013
- New tarball from official distribution

* Fri Nov 05 2021 akien <akien> 3.4-0.mga9
+ Revision: 1753971
- Version 3.4-stable

* Fri Oct 01 2021 akien <akien> 3.3.4-1.mga9
+ Revision: 1747095
- Version 3.3.4-stable

* Thu Aug 19 2021 akien <akien> 3.3.3-1.mga9
+ Revision: 1741959
- Version 3.3.3-stable

* Wed Aug 04 2021 akien <akien> 3.3.3-0.rc1.1.mga9
+ Revision: 1739226
- Version 3.3.3-rc1

* Wed May 26 2021 akien <akien> 3.3.2-2.mga9
+ Revision: 1728358
- Rebuild for bullet 3.17

* Mon May 24 2021 akien <akien> 3.3.2-1.mga9
+ Revision: 1727658
- Version 3.3.2-stable
- Build against system embree on aarch64 too now that it's available

* Tue May 18 2021 akien <akien> 3.3.1-1.mga9
+ Revision: 1725433
- Version 3.3.1-stable

* Tue May 11 2021 akien <akien> 3.3.1-0.rc1.1.mga9
+ Revision: 1722452
- Version 3.3.1-rc1
- Now builds raycaster on aarch64 with vendored embree (until we package embree 3.13.0 for aarch64)

* Fri Apr 23 2021 akien <akien> 3.3-1.mga9
+ Revision: 1718160
- Exclude lightmapper stuff ooutside x86_64, Godot's checks fail on cross-compilation to aarch64
- Disable use_static_cpp, we want to link libstdc++ dynamically for a system package
- use_udev is now the default setting, don't specify it
- Fix wrong checks to validate lightmapper build on non-x86_64 (same as embree)
- Version 3.3
- Include upstream patches to fix unbundling zlib and embree

* Thu Feb 11 2021 akien <akien> 3.2.3-5.mga8
+ Revision: 1675166
- Add upstream patch to fix TGA loader crash (security)

* Wed Dec 30 2020 akien <akien> 3.2.3-4.mga8
+ Revision: 1665653
- Rebuild for bullet 3.08

* Thu Dec 17 2020 akien <akien> 3.2.3-3.mga8
+ Revision: 1660142
- Rebuild for bullet 3.07

* Sat Oct 17 2020 akien <akien> 3.2.3-2.mga8
+ Revision: 1636577
- Rebuild for bullet 3.06

* Thu Sep 17 2020 akien <akien> 3.2.3-1.mga8
+ Revision: 1627596
- Version 3.2.3-stable
- Version 3.2.2-stable

* Tue Mar 10 2020 akien <akien> 3.2.1-1.mga8
+ Revision: 1555376
- Version 3.2.1-stable

* Thu Mar 05 2020 akien <akien> 3.2.1-0.rc2.1.mga8
+ Revision: 1554057
- Version 3.2.1 RC 2
- Fix missing unbundling of wslay

* Wed Jan 29 2020 akien <akien> 3.2-1.mga8
+ Revision: 1485019
- Version 3.2-stable
- Add bash and zsh completion scripts

* Fri Jan 17 2020 akien <akien> 3.2-0.rc1.1.mga8
+ Revision: 1481212
- Version 3.2-rc1
- Use new RPM macros %%build_cflags and %%build_ldflags to harmonize
  build flags cross-distro. Those are available on F30+ and Mageia 8+,
  so we keep a manual alias for Mageia 7.
- Cleanup RHEL7 boilerplate, no longer supporting it in the Rawhide spec

* Thu Jan 02 2020 akien <akien> 3.1.2-2.mga8
+ Revision: 1475488
- Sync spec with my Fedora package.
  It was mostly the same packaging already, this just adds some Fedora-specific cruft
  but makes maintaining cross-distro simpler.
- Resync tarball for Godot 3.1.2, it was re-released. No change affecting our Linux
  binaries.

* Sat Nov 30 2019 akien <akien> 3.1.2-1.mga8
+ Revision: 1463812
- Version 3.1.2

* Fri Apr 26 2019 akien <akien> 3.1.1-1.mga7
+ Revision: 1395597
- Version 3.1.1

* Thu Apr 18 2019 akien <akien> 3.1-2.mga7
+ Revision: 1393221
- Unbundle and build against system zstd 1.4.0

* Wed Apr 03 2019 akien <akien> 3.1-1.mga7
+ Revision: 1385635
- Version 3.1-stable
- Adds dependency on system mbedtls and miniupnpc
- Removes dependency on openssl
- Unbundled bullet now that 2.88 is available
- Bundles libwebsockets, can't build against system one for now
- Bundles tinyexr, not packaged (and likely not relevant to package)
- Rename -server build to -headless, add an actual server runtime package
- Build with LTO, improves performance a lot (but slow linking)
- Adds MIME type for .godot project files

* Tue Feb 12 2019 daviddavid <daviddavid> 3.0.6-3.mga7
+ Revision: 1365446
- rebuild for new libvpx 1.8.0

* Sun Sep 23 2018 umeabot <umeabot> 3.0.6-2.mga7
+ Revision: 1298008
- Mageia 7 Mass Rebuild

* Sat Aug 11 2018 akien <akien> 3.0.6-1.mga7
+ Revision: 1251042
- Version 3.0.6 (security update)

* Wed Jul 11 2018 akien <akien> 3.0.5-1.mga7
+ Revision: 1243061
- Version 3.0.5

* Wed Jun 20 2018 akien <akien> 3.0.3-2.mga7
+ Revision: 1238289
- Add patch to workaround GCC ICE on armv7hl

* Thu Jun 14 2018 akien <akien> 3.0.3-1.mga7
+ Revision: 1236935
- Version 3.0.3
- Fix vendoring in version string (env var changed name upstream)

* Wed Mar 14 2018 akien <akien> 3.0.2-2.mga7
+ Revision: 1209402
- Fix launch argument of desktop file

* Sun Mar 04 2018 akien <akien> 3.0.2-1.mga7
+ Revision: 1206473
- Add upstream patch to fix server platform build
- Version 3.0.2-stable

* Fri Feb 02 2018 akien <akien> 3.0-3.mga7
+ Revision: 1198620
- Update tarball to final 3.0-stable

* Fri Feb 02 2018 daviddavid <daviddavid> 3.0-2.mga7
+ Revision: 1198552
- rebuild for new libvpx 1.7.0

* Fri Jan 26 2018 akien <akien> 3.0-1.mga7
+ Revision: 1197290
- Disable LTO, seems to break debuginfo
- New upstream tarball with fixed debuginfo stripping
- Prevent stripping binaries
- Don't unbundle zstd yet as Godot uses experimental APIs exposed only in the static library
- Keep bundled bullet, needs >= 2.88 which is not released yet
- Version 3.0-stable
- No longer provide demos, they can be downloaded from the editor
- Disable server binary, not available in 3.0
- Compile with GCC and LTO
- Document bundled() provides thoroughly
- Document bundled() provides

* Sun Dec 03 2017 daviddavid <daviddavid> 2.1.4-4.mga7
+ Revision: 1180794
- rebuild for new glew 2.1.0

* Sun Sep 24 2017 akien <akien> 2.1.4-3.mga7
+ Revision: 1158526
- Add upstream patches to improve packaging:
  * P0: OpenSSL 1.1.0 support, adjust BRs accordingly
  * P1: Upstream desktop and AppStream files
  * P2: Help output improvements
  * P3: Upstream man page
- Add license files to server package
- Remove ExclusiveArch, should be possible to build on ARMv7
- Clarify why clang and openssl-compat10 are used
- Package doc for demos

* Sat Sep 23 2017 akien <akien> 2.1.4-2.mga7
+ Revision: 1157793
- Add debug_release symbols
- Enable udev support for joypads
- Package COPYRIGHT.txt and AUTHORS.md in docs

* Mon Sep 11 2017 guillomovitch <guillomovitch> 2.1.4-1.mga7
+ Revision: 1152942
- new version 2.1.4
- use llvm, as gcc 7 is not supported upstream

* Tue Apr 11 2017 akien <akien> 2.1.3-1.mga6
+ Revision: 1096424
- Version 2.1.3

* Sat Jan 21 2017 akien <akien> 2.1.2-1.mga6
+ Revision: 1082732
- Version 2.1.2-stable

* Wed Nov 16 2016 akien <akien> 2.1.1-1.mga6
+ Revision: 1067563
- Version 2.1.1
- Unbundle libraries thanks to upstream work to facilitate this:
  freetype, glew, libogg, libpng, libtheora, libvorbis, libwebp, openssl, opus, zlib
- Drop packaged templates for x11 32-bit and 64-bit
  o It was too much work for building templates just for Linux, and 32-bit systems
    would not have had access to the 64-bit templates anyway.
  o Godot 3.0 (next major) will let users download official templates directly,
    which is much better for the many supported platforms the Linux editor can
    export to.

* Tue Aug 09 2016 akien <akien> 2.1-1.mga6
+ Revision: 1045186
- Enable conditional server build, for testing purposes
- Sync new 2.1 tarball
- Add tarball for demos, provided separately upstream
- Version 2.1
  o BRs xrandr for dpi detection
  o No longer links statically against stdc++-static

* Sun Jul 10 2016 akien <akien> 2.0.4.1-1.mga6
+ Revision: 1040624
- Version 2.0.4.1, hotfix for a regression
- Version 2.0.4

* Thu Jun 16 2016 akien <akien> 2.0.3-4.mga6
+ Revision: 1021639
- Fix Comment in desktop file
- Force starting the project manager in the desktop file

* Tue May 17 2016 akien <akien> 2.0.3-3.mga6
+ Revision: 1016575
- Resync tarball with upstream, makes Patch0 obsolete

* Fri May 13 2016 akien <akien> 2.0.3-2.mga6
+ Revision: 1014571
- Patch upstream regression in ItemList

* Fri May 13 2016 akien <akien> 2.0.3-1.mga6
+ Revision: 1014421
- Version 2.0.3
- No longer compress templates with upx

* Tue Mar 08 2016 akien <akien> 2.0.1-1.mga6
+ Revision: 987284
- Version 2.0.1

* Wed Mar 02 2016 umeabot <umeabot> 2.0-3.mga6
+ Revision: 983443
- Rebuild for openssl

* Sat Feb 27 2016 akien <akien> 2.0-2.mga6
+ Revision: 979993
- Install demos (in a separate package)
- Set build revision to mageia instead of custom_build
- Use Mageia optflags and linkflags for builds (apart from debug template, no optflags)

* Tue Feb 23 2016 akien <akien> 2.0-1.mga6
+ Revision: 977125
- Version 2.0-stable

* Sun Feb 21 2016 akien <akien> 2.0-0.dev.1.mga6
+ Revision: 975107
- imported package godot

